@@ -11,7 +11,7 @@ use Env qw( @PKG_CONFIG_PATH );
 use Config ();
 
 # ABSTRACT: Build external dependencies for use in CPAN
-our $VERSION = '1.16'; # VERSION
+our $VERSION = '1.18'; # VERSION
 
 
 sub _path { goto \&Path::Tiny::path }
@@ -150,19 +150,24 @@ sub load
   
   require alienfile;
 
+  foreach my $preload (@preload)
+  {
+    ref $preload eq 'CODE' ? $preload->($self->meta) : $self->meta->apply_plugin($preload);
+  }
+
+  # TODO: do this without a string eval ?
   eval '# line '. __LINE__ . ' "' . __FILE__ . qq("\n) . qq{
     package ${class}::Alienfile;
-    foreach my \$preload (\@preload) {
-      ref \$preload eq 'CODE' ? \$preload->(meta()) : alienfile::plugin(\$preload);
-    }
     do '@{[ $file->absolute->stringify ]}';
     die \$\@ if \$\@;
-    foreach my \$postload (\@postload) {
-      ref \$postload eq 'CODE' ? \$postload->(meta()) : alienfile::plugin(\$postload);
-    }
   };
   die $@ if $@;
-  
+
+  foreach my $postload (@postload)
+  {
+    ref $postload eq 'CODE' ? $postload->($self->meta) : $self->meta->apply_plugin($postload);
+  }
+
   $self->{args} = \@args;
   unless(defined $self->meta->prop->{arch})
   {
@@ -270,8 +275,12 @@ sub load_requires
   foreach my $mod (keys %$reqs)
   {
     my $ver = $reqs->{$mod};
-    eval qq{ use $mod @{[ $ver ? $ver : '' ]} () };
-    die if $@;
+    require do {
+      my $pm = "$mod.pm";
+      $pm =~ s{::}{/}g;
+      $pm;
+    };
+    die "Required $mod $ver, have @{[ $mod->VERSION || 0 ]}" if $ver && ! $mod->VERSION($ver);
     
     # allow for requires on Alien::Build or Alien::Base
     next if $mod eq 'Alien::Build';
@@ -982,6 +991,53 @@ sub call_hook
   $value;
 }
 
+
+sub apply_plugin
+{
+  my($self, $name, @args) = @_;
+
+  my $class;
+  my $pm;
+  my $found;
+  
+  if($name =~ /^=(.*)$/)
+  {
+    $class = $1;
+    $pm    = "$class.pm";
+    $pm    =~ s!::!/!g;
+    $found = 1;
+  }
+  
+  if($name !~ /::/ && !$found)
+  {
+    foreach my $inc (@INC)
+    {
+      # TODO: allow negotiators to work with @INC hooks
+      next if ref $inc;
+      my $file = Path::Tiny->new("$inc/Alien/Build/Plugin/$name/Negotiate.pm");
+      if(-r $file)
+      {
+        $class = "Alien::Build::Plugin::${name}::Negotiate";
+        $pm    = "Alien/Build/Plugin/$name/Negotiate.pm";
+        $found = 1;
+        last;
+      }
+    }
+  }
+  
+  unless($found)
+  {
+    $class = "Alien::Build::Plugin::$name";
+    $pm    = "Alien/Build/Plugin/$name.pm";
+    $pm    =~ s{::}{/}g;
+  }
+  
+  require $pm unless $class->can('new');
+  my $plugin = $class->new(@args);
+  $plugin->init($self);
+  $self;
+}
+
 package Alien::Build::TempDir;
 
 use Path::Tiny qw( path );
@@ -1026,7 +1082,7 @@ Alien::Build - Build external dependencies for use in CPAN
 
 =head1 VERSION
 
-version 1.16
+version 1.18
 
 =head1 SYNOPSIS
 
@@ -1710,6 +1766,13 @@ a method.  For example, this will add a probe system requirement:
    },
  );
 
+=head2 apply_plugin
+
+ Alien::Build->meta->apply_plugin($name);
+ Alien::Build->meta->apply_plugin($name, @args);
+
+Apply the given plugin with the given arguments.
+
 =head1 ENVIRONMENT
 
 L<Alien::Build> responds to these environment variables:
