@@ -7,7 +7,7 @@ use constant _win => $^O eq 'MSWin32';
 use Path::Tiny ();
 
 # ABSTRACT: Autoconf plugin for Alien::Build
-our $VERSION = '1.16'; # VERSION
+our $VERSION = '1.18'; # VERSION
 
 
 has with_pic       => 1;
@@ -18,10 +18,9 @@ sub init
 {
   my($self, $meta) = @_;
   
-  require Alien::Build::Plugin::Build::MSYS;
-  Alien::Build::Plugin::Build::MSYS->new(
+  $meta->apply_plugin('Build::MSYS',
     (defined $self->msys_version ? (msys_version => $self->msys_version) : ()),
-  )->init($meta);
+  );
   
   $meta->prop->{destdir} = 1;
   $meta->prop->{autoconf} = 1;
@@ -144,7 +143,7 @@ Alien::Build::Plugin::Build::Autoconf - Autoconf plugin for Alien::Build
 
 =head1 VERSION
 
-version 1.16
+version 1.18
 
 =head1 SYNOPSIS
 
