@@ -7,7 +7,7 @@ use Module::Load ();
 use Carp ();
 
 # ABSTRACT: Download negotiation plugin
-our $VERSION = '1.16'; # VERSION
+our $VERSION = '1.18'; # VERSION
 
 
 has '+url' => sub { Carp::croak "url is a required property" };
@@ -75,19 +75,19 @@ sub init
 
   my($fetch, @decoders) = $self->pick;
   
-  $self->subplugin($fetch,
+  $meta->apply_plugin($fetch,
     url     => $self->url,
     ssl     => $self->ssl,
     ($fetch eq 'Fetch::NetFTP' ? (passive => $self->passive) : ()),
-  )->init($meta);
+  );
   
   if($self->version)
   {
-    $self->subplugin($_)->init($meta) for @decoders;
-    $self->subplugin('Prefer::SortVersions', 
+    $meta->apply_plugin($_) for @decoders;
+    $meta->apply_plugin('Prefer::SortVersions', 
       (defined $self->filter ? (filter => $self->filter) : ()),
       version => $self->version,
-    )->init($meta);
+    );
   }
 }
 
@@ -105,7 +105,7 @@ Alien::Build::Plugin::Download::Negotiate - Download negotiation plugin
 
 =head1 VERSION
 
-version 1.16
+version 1.18
 
 =head1 SYNOPSIS
 
