@@ -6,13 +6,16 @@ use Alien::Build::Plugin;
 use Carp ();
 
 # ABSTRACT: Probe system and determine library or tool properties using the pkg-config command line interface
-our $VERSION = '1.16'; # VERSION
+our $VERSION = '1.18'; # VERSION
 
 
 has '+pkg_name' => sub {
   Carp::croak "pkg_name is a required property";
 };
 
+# NOT used, for compat with other PkgConfig plugins
+has register_prereqs => 1;
+
 sub _bin_name {
 
   # We prefer pkgconf to pkg-config because it seems to be the future.
@@ -149,7 +152,7 @@ Alien::Build::Plugin::PkgConfig::CommandLine - Probe system and determine librar
 
 =head1 VERSION
 
-version 1.16
+version 1.18
 
 =head1 SYNOPSIS
 
