@@ -8,7 +8,7 @@ use File::Temp ();
 use Capture::Tiny qw( capture_merged capture );
 
 # ABSTRACT: Probe for system libraries by guessing with ExtUtils::CBuilder
-our $VERSION = '1.16'; # VERSION
+our $VERSION = '1.18'; # VERSION
 
 
 has options => sub { {} };
@@ -110,20 +110,21 @@ sub init
       my($out, $err, $ret) = capture { system($^O eq 'MSWin32' ? $exe : "./$exe") };
       die "execute failed" if $ret;
       
-      if(defined $self->version)
-      {
-        ($build->runtime_prop->{version}) = $out =~ $self->version;
-      }
-      
       my $cflags = $self->cflags;
       my $libs   = $self->libs;
       
       $cflags =~ s{\s*$}{ };
       $libs =~ s{\s*$}{ };
       
-      $build->runtime_prop->{cflags} = $cflags;
-      $build->runtime_prop->{libs}   = $libs;
-      $build->install_prop->{plugin_probe_cbuilder_gather} = 1;
+      $build->install_prop->{plugin_probe_cbuilder_gather} = {
+        cflags  => $cflags,
+        libs    => $libs,
+      };
+      
+      if(defined $self->version)
+      {
+        ($build->install_prop->{plugin_probe_cbuilder_gather}->{version}) = $out =~ $self->version;
+      }
       
       'system';
     }
@@ -132,9 +133,13 @@ sub init
   $meta->register_hook(
     gather_system => sub {
       my($build) = @_;
-      unless($build->install_prop->{plugin_probe_cbuilder_gather})
+      if(my $p = $build->install_prop->{plugin_probe_cbuilder_gather})
       {
-        die "cbuilder plugin failed to gather";
+        $build->runtime_prop->{$_} = $p->{$_} for keys %$p;
+      }
+      else
+      {
+        die "cbuilder unable to gather; if you are using multiple probe steps you may need to provide your own gather.";
       }
     },
   );
@@ -154,7 +159,7 @@ Alien::Build::Plugin::Probe::CBuilder - Probe for system libraries by guessing w
 
 =head1 VERSION
 
-version 1.16
+version 1.18
 
 =head1 SYNOPSIS
 
