@@ -26,12 +26,18 @@ our @EXPORT = qw(
 );
 
 # ABSTRACT: Tools for testing Alien::Build + alienfile
-our $VERSION = '1.16'; # VERSION
+our $VERSION = '1.18'; # VERSION
 
 
 my $build;
 my $build_alienfile;
 my $build_root;
+my $build_targ;
+
+sub alienfile::targ
+{
+  $build_targ;
+}
 
 sub alienfile
 {
@@ -40,6 +46,9 @@ sub alienfile
   $filename = path($filename)->absolute;
   my %args = @_ == 0 ? (filename => 'alienfile') : @_ % 2 ? ( source => do { '# line '. $line . ' "' . path($filename)->absolute . qq("\n) . $_[0] }) : @_;
 
+  require alienfile;
+  push @alienfile::EXPORT, 'targ' unless grep /^targ$/, @alienfile::EXPORT;
+
   my $get_temp_root = do{
     my $root; # may be undef;
     sub {
@@ -81,11 +90,12 @@ sub alienfile
   
   _alienfile_clear();
   my $out = capture_merged {
+    $build_targ = $args{targ};
     $build = Alien::Build->load($args{filename}, root => $args{root});
     $build->set_stage($args{stage});
     $build->set_prefix($args{prefix});
   };
-
+  
   my $ctx = context();
   $ctx->note($out) if $out;
   $ctx->release;
@@ -101,6 +111,7 @@ sub _alienfile_clear
   undef $build;
   undef $build_alienfile;
   undef $build_root;
+  undef $build_targ;
 }
 
 
@@ -498,7 +509,7 @@ Test::Alien::Build - Tools for testing Alien::Build + alienfile
 
 =head1 VERSION
 
-version 1.16
+version 1.18
 
 =head1 SYNOPSIS
 
